# == Class: pdagent
#
# Puppet module to install, deploy and configure pdagent.
#
class pdagent (
  $package              = true,
  $service              = true,
  $enable               = true,
  $manage_repo          = true,
  $apt_location         = $pdagent::params::apt_location,
  $apt_release          = $pdagent::params::apt_release,
  $apt_repos            = $pdagent::params::apt_repos,
  $apt_key              = $pdagent::params::apt_key,
  $pdagent_package_name = $pdagent::params::pdagent_package_name,
  $pdagent_service_name = $pdagent::params::pdagent_service_name,
) inherits pdagent::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    running : { $ensure_service = 'running' }
    default : { fail('service must be true, false or running') }
  }

  if ($manage_repo == true) {
    class { 'pdagent::repos':
      apt_location => $apt_location,
      apt_release  => $apt_release,
      apt_repos    => $apt_repos,
      apt_key      => $apt_key,
    }

    package { $pdagent_package_name:
      ensure  => $ensure_package,
      require => Class['pdagent::repos'],
    }
  }
  else {
    package { $pdagent_package_name:
      ensure  => $ensure_package,
    }
  }

  service { $pdagent_service_name:
    ensure     => $ensure_service,
    enable     => $enable,
    hasrestart => true,
    hasstatus  => true,
    require    => Package[$pdagent_package_name],
  }
}
# EOF
