# == Class: pgadent::repos
#
class pdagent::repos (
  $apt_location = $pdagent::params::apt_location,
  $apt_release  = $pdagent::params::apt_release,
  $apt_repos    = $pdagent::params::apt_repos,
  $apt_key      = $pdagent::params::apt_key,
) inherits pdagent::params {
  case $::operatingsystem {
    /(?i:debian|devuan|ubuntu)/: {
      apt::source { 'pdagent':
        ensure      => present,
        location    => $apt_location,
        release     => $apt_release,
        repos       => $apt_repos,
        key         => $apt_key,
        include_src => false,
      }
    }
    /(?i:centos|fedora|redhat)/: {
      file { '/etc/yum.repos.d/pdagent.repo':
        ensure  => present,
        backup  => true,
        content => template('pdagent/pdagent.repo.erb'),
        owner   => 'root',
        group   => 'root',
        mode    => '0644',
      }

      exec { 'pdagent yum update':
        command   => 'yum update -q -y',
        path      => [ '/usr/bin', '/usr/sbin', '/bin', '/sbin' ],
        subscribe => File['/etc/yum.repos.d/pdagent.repo'],
      }
    }
    default                    : {
      fail("Module ${module_name} is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
